@@ -24,6 +24,8 @@ class LinkTypes:
 class Status:
     OK = 'OK'
     REVIEW = 'Pending review'
+    CHECK = 'Pending check'
+    TESTING = 'Accepted for testing'
     REJECTED = 'Rejected'
     IGNORED = 'Ignored'
     PARTIAL = 'Partial solution'
@@ -50,6 +52,8 @@ class Problem:
         return 'green' if self.status == Status.OK \
             else 'green' if self.status == Status.REVIEW \
             else 'white' if self.status == Status.NOT_SUBMITTED \
+            else 'bright_yellow' if self.status == Status.CHECK \
+            else 'bright_yellow' if self.status == Status.TESTING \
             else 'red'
 
     def bold(self):
@@ -69,6 +73,10 @@ class Submission:
     def short_status(self):
         if self.status == Status.REVIEW:
             return 'Pending'
+        if self.status == Status.CHECK:
+            return 'Check'
+        if self.status == Status.TESTING:
+            return 'Testing'
         if self.status == Status.PARTIAL:
             return 'Partial'
         return self.status
@@ -118,6 +126,8 @@ class TaskScore:
     def color(self):
         return 'green' if self.status == Status.REVIEW \
             else 'green' if self.status == Status.OK \
+            else 'bright_yellow' if self.status == Status.TESTING \
+            else 'red' if self.status == Status.PARTIAL \
             else 'white'
 
     def bold(self):
@@ -273,9 +283,14 @@ def to_task_score(task_name, cell):
 
     status = Status.REVIEW if 'cell_attr_pr' in cell['class'] \
         else Status.REJECTED if 'cell_attr_rj' in cell['class'] \
+        else Status.TESTING if 'cell_attr_tr' in cell['class'] \
+        else Status.PARTIAL if score == '0'\
         else Status.OK if score is not None \
         else Status.NOT_SUBMITTED
 
+    if status == Status.TESTING and score is None:
+        score = '??'
+
     return TaskScore(extract_contest_name(task_name), task_name, score, status)
 
 
