@@ -33,7 +33,7 @@ def may_resubmit(runs):
     if len(rows) < 2:
         return True
     last_run = rows[1]
-    if last_run.find_all('td')[5].text not in [Status.OK, Status.REVIEW]:
+    if last_run.find_all('td')[5].text not in [Status.OK, Status.REVIEW, Status.TESTING, Status.CHECK]:
         return True
     return click.confirm('This problem was already solved! Submit anyway?')
 
@@ -51,8 +51,13 @@ def _get_problem_data(links, session, prob_id):
 
     runs = soup.find('table', {'class': 'table'})
     form = soup.find('form')
+
     if form is None:
         return None, 'Cannot submit a solution for this problem'
+    file = form.find('input', {'name': 'file'})
+    if file is None:
+        return None, 'Cannot submit a solution for this problem'
+
     return ProblemPage(problem_link, runs, form), ''
 
 
@@ -67,6 +72,8 @@ def compose_post_data(form):
         lang_input = form.find('input', {'name': 'lang_id'})
         if lang_input is not None:
             lang = lang_input['value']
+        else:
+            lang = None
     else:
         langs = [(opt.text, opt['value']) for opt in lang_list.find_all('option') if opt.get('value')]
         if len(langs) == 1:
@@ -74,9 +81,9 @@ def compose_post_data(form):
         else:
             lang = lang_choice(langs)[1]
 
-    data = {
-        'lang_id': lang,
-    }
+    data = {}
+    if lang is not None:
+        data['lang_id'] = lang
     for elem in form.find_all('input'):
         if elem.get('name') not in ['lang_id', 'file'] and elem.get('value') is not None:
             data[elem['name']] = elem['value']
