@@ -172,8 +172,8 @@ def print_diff(before_output, after_output, before_name, after_name):
         remove = line.startswith('-')
         color = 'red' if remove else 'green' if add else None
         click.secho(line, nl=False, fg=color)
-    if diff:
-        click.secho()
+        if not line.endswith('\n'):
+            click.secho('\n\ No newline at end of file')
 
 
 def format_file(file):
@@ -248,3 +248,10 @@ def find_test_output(input_file):
             return output_file
     return None
 
+
+def prompt_choice(text, options):
+    """Return the index of user's choice (0 ... len(options) - 1)"""
+    click.secho(f'{text}:')
+    for index, option in enumerate(options, start=1):
+        click.secho(f'{index:>4}) {option}')
+    return click.prompt('', prompt_suffix='> ', type=click.IntRange(min=1, max=len(options))) - 1
